#
# $Id: Build.PL,v aa39a8c9dab5 2015/02/21 10:31:39 gomor $
#
use strict;
use warnings;

use Module::Build;

my $builder = Module::Build->new(
   module_name => 'Net::Write::Fast',
   license => 'artistic',
   dist_author => 'GomoR <gomor_at_cpan.org>',
   dist_version_from => 'lib/Net/Write/Fast.pm',
   xs_files => { 'Fast.xs' => './Fast.xs' },
   requires => {
      'perl' => '5.6.1',
      'Exporter' => '0',
      'DynaLoader' => '0',
      'Time::Interval' => '0',
   },
   configure_requires => {
      'Module::Build' => 0,
   },
);

$builder->create_build_script;
